@@ -1,5 +1,6 @@
 import os
 import tempfile
+from unittest.mock import MagicMock
 
 import pytest
 from tree_sitter import Point
@@ -159,6 +160,24 @@ def bar():
     os.remove(test_file)
 
 
+def test_treesitter_chunker_fallback_on_long_node():
+    test_content = r"""
+def foo():
+    return "a very very very very very long string"
+    """
+    config = Config(chunk_size=15)
+    with (
+        tempfile.NamedTemporaryFile(
+            mode="w", delete=False, suffix=".py"
+        ) as temp_py_file,
+    ):
+        temp_py_file.write(test_content)
+    ts_chunker = TreeSitterChunker(config)
+    ts_chunker._fallback_chunker.chunk = MagicMock()
+    list(ts_chunker.chunk(temp_py_file.name))
+    ts_chunker._fallback_chunker.chunk.assert_called_once()
+
+
 def test_treesitter_chunker_python_encoding():
     """Test TreeSitterChunker with a sample file using tempfile."""
     chunker = TreeSitterChunker(Config(chunk_size=30, encoding="gbk"))
